# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKDeconvolutionPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkIterativeDeconvolutionImageFilterPython
else:
    import _itkIterativeDeconvolutionImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkIndexPython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.itkFFTConvolutionImageFilterPython
import itk.itkConvolutionImageFilterBasePython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageBoundaryConditionPython
class itkIterativeDeconvolutionImageFilterIF2IF2(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterIF2IF2):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD2"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD2
        GetCurrentEstimate(self) -> itkImageD2
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_cast(obj)

# Register itkIterativeDeconvolutionImageFilterIF2IF2 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF2IF2_swigregister(itkIterativeDeconvolutionImageFilterIF2IF2)
class itkIterativeDeconvolutionImageFilterIF3IF3(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterIF3IF3):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD3"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD3
        GetCurrentEstimate(self) -> itkImageD3
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_cast(obj)

# Register itkIterativeDeconvolutionImageFilterIF3IF3 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIF3IF3_swigregister(itkIterativeDeconvolutionImageFilterIF3IF3)
class itkIterativeDeconvolutionImageFilterISS2ISS2(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterISS2ISS2):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD2"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD2
        GetCurrentEstimate(self) -> itkImageD2
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_cast(obj)

# Register itkIterativeDeconvolutionImageFilterISS2ISS2 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS2ISS2_swigregister(itkIterativeDeconvolutionImageFilterISS2ISS2)
class itkIterativeDeconvolutionImageFilterISS3ISS3(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterISS3ISS3):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD3"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD3
        GetCurrentEstimate(self) -> itkImageD3
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_cast(obj)

# Register itkIterativeDeconvolutionImageFilterISS3ISS3 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterISS3ISS3_swigregister(itkIterativeDeconvolutionImageFilterISS3ISS3)
class itkIterativeDeconvolutionImageFilterIUC2IUC2(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterIUC2IUC2):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD2"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD2
        GetCurrentEstimate(self) -> itkImageD2
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_cast(obj)

# Register itkIterativeDeconvolutionImageFilterIUC2IUC2 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC2IUC2_swigregister(itkIterativeDeconvolutionImageFilterIUC2IUC2)
class itkIterativeDeconvolutionImageFilterIUC3IUC3(itk.itkFFTConvolutionImageFilterPython.itkFFTConvolutionImageFilterIUC3IUC3):
    r"""Proxy of C++ itkIterativeDeconvolutionImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetNumberOfIterations(self, _arg):
        r"""
        SetNumberOfIterations(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_SetNumberOfIterations(self, _arg)

    def GetNumberOfIterations(self):
        r"""GetNumberOfIterations(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_GetNumberOfIterations(self)

    def GetModifiableCurrentEstimate(self):
        r"""GetModifiableCurrentEstimate(self) -> itkImageD3"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_GetModifiableCurrentEstimate(self)

    def GetCurrentEstimate(self, *args):
        r"""
        GetCurrentEstimate(self) -> itkImageD3
        GetCurrentEstimate(self) -> itkImageD3
        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_GetCurrentEstimate(self, *args)

    def SetStopIteration(self, stop):
        r"""
        SetStopIteration(self, stop)

        Parameters
        ----------
        stop: bool

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_SetStopIteration(self, stop)

    def GetStopIteration(self):
        r"""GetStopIteration(self) -> bool"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_GetStopIteration(self)

    def GetIteration(self):
        r"""GetIteration(self) -> unsigned int"""
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_GetIteration(self)
    __swig_destroy__ = _itkIterativeDeconvolutionImageFilterPython.delete_itkIterativeDeconvolutionImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIterativeDeconvolutionImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_cast(obj)

# Register itkIterativeDeconvolutionImageFilterIUC3IUC3 in _itkIterativeDeconvolutionImageFilterPython:
_itkIterativeDeconvolutionImageFilterPython.itkIterativeDeconvolutionImageFilterIUC3IUC3_swigregister(itkIterativeDeconvolutionImageFilterIUC3IUC3)

